# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - Queue changes for review

    Queue changed pages edited by unprivileged users for review by the
    ApproveChanges action.

    @copyright: 2011 Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL, see COPYING for details.
"""

from MoinMoin.PageEditor import PageEditor
from MoinMoin.events import PagePreSaveEvent, Abort
from ApproveChangesSupport import *

def handle_presave(event):
    request = event.request
    _ = request.getText

    approved_editors_group = get_approved_editors_group(request)
    queued_changes_page = get_queued_changes_page(request)

    pagename = event.page_editor.page_name

    # Saving into queues has to be permitted or the mechanism will keep trying
    # to save into a queue of the specified page.

    if is_queued_changes_page(request, pagename):

        # NOTE: Add ACL to prevent normal users from seeing the page anywhere.
        # NOTE: (to-do/hide-queued-pages.txt)

        return None

    # For normal pages, the user has to be approved. Otherwise, the page will be
    # saved into a queue.

    elif not request.user.valid or (
        not request.dicts.has_member(approved_editors_group, request.user.name) and \
        not request.user.isSuperUser()):

        # Save the page in the queue.
        # NOTE: Record the parent revision.
        # NOTE: (to-do/record-parent-for-proper-merges.txt)

        new_page = PageEditor(request, "%s/%s" % (pagename, queued_changes_page))

        try:
            new_page.saveText(event.new_text, 0)
        except PageEditor.Unchanged:
            pass

        # Abort the page save operation.

        return Abort(_("Your changes have been queued for approval."))

def handle(event):
    if isinstance(event, PagePreSaveEvent):
        return handle_presave(event)

# vim: tabstop=4 expandtab shiftwidth=4
